==> FrontISTR-v4.1.tar.gz: FrontISTR-v4.1/hecmw1/src/solver/communication/hecmw_solver_SR_11_dumm.f90 <==
!======================================================================!
!                                                                      !
!   Software Name : HEC-MW Library for PC-cluster                      !
!         Version : 2.3                                                !
!                                                                      !
!     Last Update : 2006/06/01                                         !
!        Category : Linear Solver                                      !
!                                                                      !
!            Written by Kengo Nakajima (Univ. of Tokyo)                !
!                                                                      !
!     Contact address :  IIS,The University of Tokyo RSS21 project     !
!                                                                      !
!     "Structural Analysis System for General-purpose Coupling         !
!      Simulations Using High End Computing Middleware (HEC-MW)"       !
!                                                                      !
!======================================================================!
!C DUMMY SUBROUTINE
!C*** 
!C*** module hecmw_solver_SR_11
!C***
!
      module hecmw_solver_SR_11
      contains
!C
!C*** SOLVER_SEND_RECV
!C
      subroutine  hecmw_solve_SEND_RECV_11                              &
     &                ( N, NEIBPETOT, NEIBPE, STACK_IMPORT, NOD_IMPORT, &
     &                                        STACK_EXPORT, NOD_EXPORT, &
     &                  WS, WR, X, SOLVER_COMM,my_rank)

      use hecmw_util
      implicit REAL*8 (A-H,O-Z)

      integer(kind=kint )                , intent(in)   ::  N
      integer(kind=kint )                , intent(in)   ::  NEIBPETOT
      integer(kind=kint ), pointer :: NEIBPE      (:)
      integer(kind=kint ), pointer :: STACK_IMPORT(:)
      integer(kind=kint ), pointer :: NOD_IMPORT  (:)
      integer(kind=kint ), pointer :: STACK_EXPORT(:)
      integer(kind=kint ), pointer :: NOD_EXPORT  (:)
      real   (kind=kreal), dimension(N)  , intent(inout):: WS
      real   (kind=kreal), dimension(N)  , intent(inout):: WR
      real   (kind=kreal), dimension(N)  , intent(inout):: X
      integer(kind=kint)                 , intent(in)   ::SOLVER_COMM
      integer(kind=kint)                 , intent(in)   :: my_rank

      end subroutine hecmw_solve_SEND_RECV_11
      end module     hecmw_solver_SR_11

==> FrontISTR-v4.3.tar.gz: FrontISTR-v4.3/hecmw1/src/solver/communication/hecmw_solver_SR_11_dumm.f90 <==
!======================================================================!
!                                                                      !
!   Software Name : HEC-MW Library for PC-cluster                      !
!         Version : 2.6                                                !
!                                                                      !
!     Last Update : 2006/06/01                                         !
!        Category : Linear Solver                                      !
!                                                                      !
!            Written by Kengo Nakajima (Univ. of Tokyo)                !
!                                                                      !
!     Contact address :  IIS,The University of Tokyo RSS21 project     !
!                                                                      !
!     "Structural Analysis System for General-purpose Coupling         !
!      Simulations Using High End Computing Middleware (HEC-MW)"       !
!                                                                      !
!======================================================================!
!C DUMMY SUBROUTINE
!C*** 
!C*** module hecmw_solver_SR_11
!C***
!
      module hecmw_solver_SR_11
      contains
!C
!C*** SOLVER_SEND_RECV
!C
      subroutine  hecmw_solve_SEND_RECV_11                              &
     &                ( N, NEIBPETOT, NEIBPE, STACK_IMPORT, NOD_IMPORT, &
     &                                        STACK_EXPORT, NOD_EXPORT, &
     &                  WS, WR, X, SOLVER_COMM,my_rank)

      use hecmw_util
      implicit REAL*8 (A-H,O-Z)

      integer(kind=kint )                , intent(in)   ::  N
      integer(kind=kint )                , intent(in)   ::  NEIBPETOT
      integer(kind=kint ), pointer :: NEIBPE      (:)
      integer(kind=kint ), pointer :: STACK_IMPORT(:)
      integer(kind=kint ), pointer :: NOD_IMPORT  (:)
      integer(kind=kint ), pointer :: STACK_EXPORT(:)
      integer(kind=kint ), pointer :: NOD_EXPORT  (:)
      real   (kind=kreal), dimension(:)  , intent(inout):: WS
      real   (kind=kreal), dimension(:)  , intent(inout):: WR
      real   (kind=kreal), dimension(:)  , intent(inout):: X
      integer(kind=kint)                 , intent(in)   ::SOLVER_COMM
      integer(kind=kint)                 , intent(in)   :: my_rank

      end subroutine hecmw_solve_SEND_RECV_11
      end module     hecmw_solver_SR_11
